@@ -2,7 +2,7 @@
  * Routines for X.518 (X.500 Distributed Operations)  packet dissection
  * Graeme Lunt 2005
  *
- * $Id: packet-dsp-template.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-dsp-template.c 38122 2011-07-19 18:48:31Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -95,7 +95,7 @@ dissect_dsp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 	}
 
 	if(parent_tree){
-		item = proto_tree_add_item(parent_tree, proto_dsp, tvb, 0, -1, FALSE);
+		item = proto_tree_add_item(parent_tree, proto_dsp, tvb, 0, -1, ENC_NA);
 		tree = proto_item_add_subtree(item, ett_dsp);
 	}
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "DAP");
