@@ -2,7 +2,7 @@
  * Routines for RFC3739 PKIXqualified packet dissection
  *  Ronnie Sahlberg 2004
  *
- * $Id: packet-pkixqualified-template.c 30516 2009-10-11 16:24:29Z stig $
+ * $Id: packet-pkixqualified-template.c 32417 2010-04-07 16:54:29Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -31,9 +31,6 @@
 #include <epan/packet.h>
 #include <epan/asn1.h>
 
-#include <stdio.h>
-#include <string.h>
-
 #include "packet-ber.h"
 #include "packet-pkixqualified.h"
 #include "packet-x509af.h"
