@@ -3,7 +3,7 @@
  * Copyright 2004 - 2005, Tim Endean <endeant@hotmail.com>
  * Built from the gsm-map dissector Copyright 2004 - 2005, Anders Broman <anders.broman@ericsson.com>
  *
- * $Id: packet-tcap-template.c 39472 2011-10-19 17:59:47Z etxrab $
+ * $Id: packet-tcap-template.c 39954 2011-11-20 08:59:19Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -129,11 +129,11 @@ extern void delete_itu_tcap_subdissector(guint32 ssn, dissector_handle_t dissect
 }
 
 dissector_handle_t get_ansi_tcap_subdissector(guint32 ssn) {
-    return g_hash_table_lookup(ansi_sub_dissectors,GUINT_TO_POINTER(ssn));
+    return (dissector_handle_t)g_hash_table_lookup(ansi_sub_dissectors,GUINT_TO_POINTER(ssn));
 }
 
 dissector_handle_t get_itu_tcap_subdissector(guint32 ssn) {
-    return g_hash_table_lookup(itu_sub_dissectors,GUINT_TO_POINTER(ssn));
+    return (dissector_handle_t)g_hash_table_lookup(itu_sub_dissectors,GUINT_TO_POINTER(ssn));
 }
 
 
@@ -160,7 +160,7 @@ dissect_tcap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
     struct tcaphash_context_t * p_tcap_context;
     dissector_handle_t subdissector_handle;
 	asn1_ctx_t asn1_ctx;
-	gint8 class;
+	gint8 ber_class;
 	gboolean pc;
 	gint tag;
 
@@ -176,9 +176,9 @@ dissect_tcap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 	 *
 	 *
 	 */
-	get_ber_identifier(tvb, 0, &class, &pc, &tag);
+	get_ber_identifier(tvb, 0, &ber_class, &pc, &tag);
 
-	if(class == BER_CLASS_PRI){
+	if(ber_class == BER_CLASS_PRI){
 		switch(tag){
 		case 1:
 		case 2:
@@ -431,7 +431,7 @@ dissect_tcap_param(asn1_ctx_t *actx, proto_tree *tree, tvbuff_t *tvb, int offset
     tvbuff_t	*next_tvb;
     proto_tree *subtree;
     proto_item *pi;
-    gint8 class;
+    gint8 ber_class;
     gboolean pc;
     gint32 tag;
     guint32 len;
@@ -443,7 +443,7 @@ dissect_tcap_param(asn1_ctx_t *actx, proto_tree *tree, tvbuff_t *tvb, int offset
     {
         saved_offset = offset;
 
-        offset = get_ber_identifier(tvb, offset, &class, &pc, &tag);
+        offset = get_ber_identifier(tvb, offset, &ber_class, &pc, &tag);
         tag_offset = offset;
         offset = get_ber_length(tvb, offset, &len, &ind_field);
         len_offset = offset;
@@ -461,7 +461,7 @@ dissect_tcap_param(asn1_ctx_t *actx, proto_tree *tree, tvbuff_t *tvb, int offset
                 saved_offset, tag_length, tag,
                 "CONSTRUCTOR Tag");
             proto_tree_add_uint(subtree, hf_tcap_tag, tvb, saved_offset,
-                tag_length, class);
+                tag_length, ber_class);
 
             proto_tree_add_uint(subtree, hf_tcap_length, tvb, tag_offset,
                 len_length, len);
