@@ -2,7 +2,7 @@
 #
 # Run this to generate all the initial makefiles.
 #
-# $Id: autogen.sh 38447 2011-08-10 15:28:29Z morriss $
+# $Id: autogen.sh 50437 2013-07-07 21:22:06Z guy $
 
 DIE=true
 PROJECT="Wireshark"
@@ -123,7 +123,12 @@ $AUTOMAKE --add-missing --gnu $am_opt || exit 1
 echo $AUTOCONF
 $AUTOCONF || exit 1
 
-#./configure "$@" || exit 1
+if [ `uname -s` = Darwin ] ; then
+    echo
+    echo "To configure Wireshark on OS X, you will need to type:"
+    echo "export PKG_CONFIG_PATH=/usr/local/lib/pkgconfig:/usr/X11/lib/pkgconfig"
+    echo "before you can run configure."
+fi
 
 echo
 echo "Now type \"./configure [options]\" and \"make\" to compile $PROJECT."
