@@ -3,7 +3,7 @@
  * Routines for BT-DHT dissection
  * Copyright 2011, Xiao Xiangquan <xiaoxiangquan@gmail.com>
  *
- * $Id: packet-bt-dht.c 49264 2013-05-13 16:25:40Z gerald $
+ * $Id: packet-bt-dht.c 49773 2013-06-04 19:53:21Z martink $
  *
  * A plugin for BT-DHT packet:
  *
@@ -273,6 +273,10 @@ dissect_bt_dht_values(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint
       offset += string_len;
     }
   }
+
+  if (tvb_get_guint8(tvb,offset)=='e') /* list ending delimiter */
+    offset++;
+
   proto_item_set_text( ti, "%s: %d peers", label, peer_index );
   col_append_fstr( pinfo->cinfo, COL_INFO, "reply=%d peers  ", peer_index );
   *result = ep_strdup_printf("%d peers", peer_index);
