@@ -5,7 +5,7 @@
  * Refactored for wireshark checkin
  *   Ronnie Sahlberg 2006
  *
- * $Id: packet-btsdp.c 41502 2012-03-12 14:38:59Z wmeier $
+ * $Id: packet-btsdp.c 50251 2013-06-30 12:24:29Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -269,7 +269,13 @@ get_type_length(tvbuff_t *tvb, int offset, int *length)
         break;
     }
 
-    *length = size;
+    if (size < 0) {
+        *length = 0; /* Add expert info? */
+    }
+    else {
+        *length = size;
+    }
+
     return offset;
 }
 
