@@ -1,7 +1,7 @@
 /* packet-fmp_notify.c
  * Routines for fmp dissection
  *
- * $Id: packet-fmp_notify.c 45501 2012-10-12 19:34:15Z wmeier $
+ * $Id: packet-fmp_notify.c 47498 2013-02-05 15:16:15Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -487,13 +487,31 @@ proto_register_fmp_notify(void)
                         "Status", "fmp_notify.status", FT_UINT32, BASE_DEC,
                         VALS(fmp_status_vals), 0, "Reply Status", HFILL }},
 
+               { &hf_fmp_extentList_len, {
+                       "Extent List length", "fmp_notify.extentListLength",
+                       FT_UINT32, BASE_DEC, NULL, 0, NULL, HFILL }},
+
+               { &hf_fmp_numBlks, {
+                       "Number Blocks", "fmp_notify.numBlks", FT_UINT32,
+                       BASE_DEC, NULL, 0, NULL, HFILL }},
+
+               { &hf_fmp_volID, {
+                       "Volume ID", "fmp_notify.volID", FT_UINT32,
+                       BASE_DEC, NULL, 0, NULL, HFILL }},
+
+               { &hf_fmp_startOffset, {
+                       "Start Offset", "fmp_notify.startOffset", FT_UINT32,
+                       BASE_DEC, NULL, 0, NULL, HFILL }},
+
+               { &hf_fmp_extent_state, {
+                       "Extent State", "fmp_notify.extentState", FT_UINT32,
+                       BASE_DEC, NULL, 0, NULL, HFILL }},
 
 		{ &hf_fmp_handleListLen, {
 			"Number File Handles", "fmp_notify.handleListLength",
 			FT_UINT32, BASE_DEC, NULL, 0,
 			"Number of File Handles", HFILL }},
 
-
 		{ &hf_fmp_sessionHandle, {
                         "Session Handle", "fmp_notify.sessHandle", FT_BYTES, BASE_NONE,
                         NULL, 0, "FMP Session Handle", HFILL }},
