@@ -2,7 +2,7 @@
  * Routines for LISP Data Message dissection
  * Copyright 2010, Lorand Jakab <lj@lispmon.net>
  *
- * $Id: packet-lisp-data.c 41724 2012-03-21 18:20:44Z wmeier $
+ * $Id: packet-lisp-data.c 49267 2013-05-13 17:40:49Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -31,8 +31,9 @@
 #include <glib.h>
 
 #include <epan/packet.h>
+#include <epan/expert.h>
 
-/* See draft-ietf-lisp-07 "Locator/ID Separation Protocol (LISP)" */
+/* See RFC 6830 "Locator/ID Separation Protocol (LISP)" */
 
 /*  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
  *  |N|L|E|V|I|flags|            Nonce/Map-Version                  |
@@ -41,6 +42,7 @@
  *  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
  */
 
+#define LISP_CONTROL_PORT       4342
 #define LISP_DATA_PORT          4341
 #define LISP_DATA_HEADER_LEN    8       /* Number of bytes in LISP data header */
 
@@ -76,7 +78,7 @@ static gint ett_lisp_data_mapver = -1;
 
 static dissector_handle_t ipv4_handle;
 static dissector_handle_t ipv6_handle;
-static dissector_handle_t data_handle;
+static dissector_handle_t lisp_handle;
 
 /* Code to actually dissect the packets */
 static int
@@ -91,8 +93,12 @@ dissect_lisp_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     proto_tree *lisp_data_tree;
     proto_tree *lisp_data_flags_tree;
 
+    /* Check if we have a LISP control packet */
+    if (pinfo->destport == LISP_CONTROL_PORT)
+        return call_dissector(lisp_handle, tvb, pinfo, tree);
+
     /* Check that there's enough data */
-    if (tvb_length(tvb) < LISP_DATA_HEADER_LEN)
+    if (tvb_reported_length(tvb) < LISP_DATA_HEADER_LEN)
         return 0;
 
     /* Make entries in Protocol column and Info column on summary display */
@@ -100,8 +106,6 @@ dissect_lisp_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
     col_set_str(pinfo->cinfo, COL_INFO, "LISP Encapsulation Header");
 
-    if (tree) {
-
         /* create display subtree for the protocol */
         ti = proto_tree_add_item(tree, proto_lisp_data, tvb, 0,
                 LISP_DATA_HEADER_LEN, ENC_NA);
@@ -130,13 +134,13 @@ dissect_lisp_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         offset += 1;
 
         if (flags&LISP_DATA_FLAG_E && !(flags&LISP_DATA_FLAG_N)) {
-            proto_tree_add_text(lisp_data_tree, tvb, offset, 0,
-                    "Invalid flag combination: if E is set, N MUST be set");
+            expert_add_info_format(pinfo, tif, PI_PROTOCOL, PI_WARN,
+                "Invalid flag combination: if E is set, N MUST be set");
         }
 
         if (flags&LISP_DATA_FLAG_N) {
             if (flags&LISP_DATA_FLAG_V) {
-                proto_tree_add_text(lisp_data_tree, tvb, offset, 0,
+                expert_add_info_format(pinfo, tif, PI_PROTOCOL, PI_WARN,
                         "Invalid flag combination: N and V can't be set both");
             }
             proto_tree_add_item(lisp_data_tree,
@@ -175,7 +179,6 @@ dissect_lisp_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 offset += 4;
             }
         }
-    }
 
     /* Check if there is stuff left in the buffer, and return if not */
 
@@ -185,17 +188,14 @@ dissect_lisp_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     switch (ip_ver) {
         case 4:
             call_dissector(ipv4_handle, next_tvb, pinfo, tree);
-            break;
+            return tvb_reported_length(tvb);
         case 6:
             call_dissector(ipv6_handle, next_tvb, pinfo, tree);
-            break;
-        default:
-            call_dissector(data_handle, next_tvb, pinfo, tree);
-            break;
+            return tvb_reported_length(tvb);
     }
 
     /* Return the amount of data this dissector was able to dissect */
-    return tvb_length(tvb);
+    return LISP_DATA_HEADER_LEN;
 }
 
 
@@ -285,7 +285,7 @@ proto_reg_handoff_lisp_data(void)
     dissector_add_uint("udp.port", LISP_DATA_PORT, lisp_data_handle);
     ipv4_handle = find_dissector("ip");
     ipv6_handle = find_dissector("ipv6");
-    data_handle = find_dissector("data");
+    lisp_handle = find_dissector("lisp");
 }
 
 /*
