@@ -3,7 +3,7 @@
  * Copyright 2010, Alexis La Goutte <alexis.lagoutte at gmail dot com>
  * BSON dissection added 2011, Thomas Buchanan <tom at thomasbuchanan dot com>
  *
- * $Id: packet-mongo.c 44342 2012-08-08 15:56:25Z gerald $
+ * $Id: packet-mongo.c 45484 2012-10-11 20:45:24Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -424,7 +424,7 @@ dissect_mongo_reply(tvbuff_t *tvb, packet_info *pinfo, guint offset, proto_tree
   number_returned = tvb_get_letohl(tvb, offset);
   offset += 4;
 
-  for (i=1; i <= number_returned; i++)
+  for (i=0; i < number_returned; i++)
   {
     offset += dissect_bson_document(tvb, pinfo, offset, tree, hf_mongo_document, 1);
   }
