@@ -1,7 +1,7 @@
 /* packet-mount.c
  * Routines for mount dissection
  *
- * $Id: packet-mount.c 39288 2011-10-06 03:35:44Z wmeier $
+ * $Id: packet-mount.c 48078 2013-03-05 01:11:22Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -169,7 +169,7 @@ dissect_mount_dirpath_call(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		if(civ->request && (civ->proc==1)){
 			const gchar *host;
 			unsigned char *name;
-			int len;
+			guint32 len;
 			unsigned char *ptr;
 
 			host=ip_to_str(pinfo->dst.data);
