@@ -1,7 +1,7 @@
 /* packet-mrdisc.c   2001 Ronnie Sahlberg <See AUTHORS for email>
  * Routines for IGMP/MRDISC packet disassembly
  *
- * $Id: packet-mrdisc.c 32410 2010-04-06 21:14:01Z wmeier $
+ * $Id: packet-mrdisc.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -88,7 +88,7 @@ dissect_mrdisc_mra(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, i
 	guint16 num;
 
 	/* Advertising Interval */
-	proto_tree_add_item(parent_tree, hf_advint, tvb, offset, 1, FALSE);
+	proto_tree_add_item(parent_tree, hf_advint, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset += 1;
 
 	/* checksum */
@@ -112,7 +112,7 @@ dissect_mrdisc_mra(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, i
 		int old_offset = offset;
 
 		item = proto_tree_add_item(parent_tree, hf_options,
-			tvb, offset, -1, FALSE);
+			tvb, offset, -1, ENC_NA);
 		tree = proto_item_add_subtree(item, ett_options);
 
 		type = tvb_get_guint8(tvb, offset);
@@ -134,7 +134,7 @@ dissect_mrdisc_mra(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, i
 			if (len != 2)
 				THROW(ReportedBoundsError);
 			proto_tree_add_item(tree, hf_qi, tvb, offset, len,
-				FALSE);
+				ENC_BIG_ENDIAN);
 			offset += len;
 			break;
 		case MRDISC_RV:
@@ -147,7 +147,7 @@ dissect_mrdisc_mra(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, i
 			if (len != 2)
 				THROW(ReportedBoundsError);
 			proto_tree_add_item(tree, hf_rv, tvb, offset, len,
-				FALSE);
+				ENC_BIG_ENDIAN);
 			offset += len;
 			break;
 		default:
@@ -156,7 +156,7 @@ dissect_mrdisc_mra(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, i
 			}
 
 			proto_tree_add_item(tree, hf_option_bytes,
-				tvb, offset, len, FALSE);
+				tvb, offset, len, ENC_NA);
 			offset += len;
 		}
 		if (item) {
@@ -197,7 +197,7 @@ dissect_mrdisc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, int o
 		return offset+tvb_length_remaining(tvb, offset);
 	}
 
-	item = proto_tree_add_item(parent_tree, proto_mrdisc, tvb, offset, 0, FALSE);
+	item = proto_tree_add_item(parent_tree, proto_mrdisc, tvb, offset, 0, ENC_NA);
 	tree = proto_item_add_subtree(item, ett_mrdisc);
 
 
