@@ -14,7 +14,7 @@
  * Updated for ANSI, Chinese ITU, and Japan support by
  *  Jeff Morriss <jeff.morriss.ws [AT] gmail.com>
  *
- * $Id: packet-mtp3.c 39153 2011-09-26 17:50:54Z etxrab $
+ * $Id: packet-mtp3.c 40910 2012-02-07 02:19:11Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -49,6 +49,8 @@
 #include <epan/prefs.h>
 #include <epan/emem.h>
 #include "packet-q708.h"
+#include "packet-sccp.h"
+#include "packet-frame.h"
 
 /* Initialize the protocol and registered fields */
 static int proto_mtp3  = -1;
@@ -116,6 +118,17 @@ static gint japan_pc_structure = JAPAN_PC_STRUCTURE_NONE;
 
 #include <packet-mtp3.h>
 gint mtp3_standard = ITU_STANDARD;
+gboolean mtp3_heuristic_standard = FALSE;
+
+static gint pref_mtp3_standard;
+
+const value_string mtp3_standard_vals[] = {
+	{ ITU_STANDARD,			"ITU_STANDARD" },
+	{ ANSI_STANDARD,		"ANSI_STANDARD" },
+	{ CHINESE_ITU_STANDARD,		"CHINESE_ITU_STANDARD" },
+	{ JAPAN_STANDARD,		"JAPAN_STANDARD" },
+	{ 0,				NULL }
+};
 
 static gboolean mtp3_use_ansi_5_bit_sls = FALSE;
 static gboolean mtp3_use_japan_5_bit_sls = FALSE;
@@ -170,49 +183,49 @@ static mtp3_addr_pc_t* mtp3_addr_opc;
 
 /* the higher values are taken from the M3UA RFC */
 static const value_string mtp3_service_indicator_code_vals[] = {
-        { 0x0,  "Signalling Network Management Message (SNM)" },
-        { 0x1,  "Maintenance Regular Message (MTN)" },
-        { 0x2,  "Maintenance Special Message (MTNS)" },
-        { 0x3,  "SCCP" },
-        { 0x4,  "TUP" },
-        { 0x5,  "ISUP" },
-        { 0x6,  "DUP (call and circuit related messages)" },
-        { 0x7,  "DUP (facility registration and cancellation message)" },
-        { 0x8,  "MTP testing user part" },
-        { 0x9,  "Broadband ISUP" },
-        { 0xa,  "Satellite ISUP" },
-        { 0xb,  "Spare" },
-        { 0xc,  "AAL type2 Signaling" },
-        { 0xd,  "Bearer Independent Call Control (BICC)" },
-        { 0xe,  "Gateway Control Protocol" },
-        { 0xf,  "Spare" },
-        { 0,    NULL }
+	{ MTP_SI_SNM,		"Signalling Network Management Message (SNM)" },
+	{ MTP_SI_MTN,		"Maintenance Regular Message (MTN)" },
+	{ MTP_SI_MTNS,		"Maintenance Special Message (MTNS)" },
+	{ MTP_SI_SCCP,		"SCCP" },
+	{ MTP_SI_TUP,		"TUP" },
+	{ MTP_SI_ISUP,		"ISUP" },
+	{ MTP_SI_DUP_CC,	"DUP (call and circuit related messages)" },
+	{ MTP_SI_DUP_FAC,	"DUP (facility registration and cancellation message)" },
+	{ MTP_SI_MTP_TEST,	"MTP testing user part" },
+	{ MTP_SI_ISUP_B,	"Broadband ISUP" },
+	{ MTP_SI_ISUP_S,	"Satellite ISUP" },
+	{ 0xb,			"Spare" },
+	{ MTP_SI_AAL2,		"AAL type2 Signaling" },
+	{ MTP_SI_BICC,		"Bearer Independent Call Control (BICC)" },
+	{ MTP_SI_GCP,		"Gateway Control Protocol" },
+	{ 0xf,			"Spare" },
+	{ 0,    		NULL }
 };
 
 const value_string mtp3_service_indicator_code_short_vals[] = {
-        { 0x0,  "SNM" },
-        { 0x1,  "MTN" },
-        { 0x2,  "MTNS" },
-        { 0x3,  "SCCP" },
-        { 0x4,  "TUP" },
-        { 0x5,  "ISUP" },
-        { 0x6,  "DUP (CC)" },
-        { 0x7,  "DUP (FAC/CANC)" },
-        { 0x8,  "MTP Test" },
-        { 0x9,  "ISUP-b" },
-        { 0xa,  "ISUP-s" },
-        { 0xc,  "AAL type 2" },
-        { 0xd,  "BICC" },
-        { 0xe,  "GCP" },
-        { 0,    NULL }
+	{ MTP_SI_SNM,		"SNM" },
+	{ MTP_SI_MTN,		"MTN" },
+	{ MTP_SI_MTNS,		"MTNS" },
+	{ MTP_SI_SCCP,		"SCCP" },
+	{ MTP_SI_TUP,		"TUP" },
+	{ MTP_SI_ISUP,		"ISUP" },
+	{ MTP_SI_DUP_CC,	"DUP (CC)" },
+	{ MTP_SI_DUP_FAC,	"DUP (FAC/CANC)" },
+	{ MTP_SI_MTP_TEST,	"MTP Test" },
+	{ MTP_SI_ISUP_B,	"ISUP-b" },
+	{ MTP_SI_ISUP_S,	"ISUP-s" },
+	{ MTP_SI_AAL2,		"AAL type 2" },
+	{ MTP_SI_BICC,		"BICC" },
+	{ MTP_SI_GCP,		"GCP" },
+	{ 0,			NULL }
 };
 
 static const value_string network_indicator_vals[] = {
-        { 0x0,  "International network" },
-        { 0x1,  "Spare (for international use only)" },
-        { 0x2,  "National network" },
-        { 0x3,  "Reserved for national use" },
-        { 0,    NULL }
+	{ 0x0,  "International network" },
+	{ 0x1,  "Spare (for international use only)" },
+	{ 0x2,  "National network" },
+	{ 0x3,  "Reserved for national use" },
+	{ 0,    NULL }
 };
 
 static dissector_handle_t data_handle;
@@ -229,19 +242,19 @@ mtp3_pc_to_str_buf(const guint32 pc, gchar *buf, int buf_len)
   {
     case ITU_STANDARD:
       switch (itu_pc_structure) {
-        case ITU_PC_STRUCTURE_NONE:
-          g_snprintf(buf, buf_len, "%u", pc);
-          break;
-        case ITU_PC_STRUCTURE_3_8_3:
-          /* this format is used in international ITU networks */
-          g_snprintf(buf, buf_len, "%u-%u-%u", (pc & 0x3800)>>11, (pc & 0x7f8) >> 3, (pc & 0x07) >> 0);
-          break;
-        case ITU_PC_STRUCTURE_4_3_4_3:
-          /* this format is used in some national ITU networks, the German one for example. */
-          g_snprintf(buf, buf_len, "%u-%u-%u-%u", (pc & 0x3c00) >>10, (pc & 0x0380) >> 7, (pc & 0x0078) >> 3, (pc & 0x0007) >> 0);
-          break;
-        default:
-          DISSECTOR_ASSERT_NOT_REACHED();
+	case ITU_PC_STRUCTURE_NONE:
+	  g_snprintf(buf, buf_len, "%u", pc);
+	  break;
+	case ITU_PC_STRUCTURE_3_8_3:
+	  /* this format is used in international ITU networks */
+	  g_snprintf(buf, buf_len, "%u-%u-%u", (pc & 0x3800)>>11, (pc & 0x7f8) >> 3, (pc & 0x07) >> 0);
+	  break;
+	case ITU_PC_STRUCTURE_4_3_4_3:
+	  /* this format is used in some national ITU networks, the German one for example. */
+	  g_snprintf(buf, buf_len, "%u-%u-%u-%u", (pc & 0x3c00) >>10, (pc & 0x0380) >> 7, (pc & 0x0078) >> 3, (pc & 0x0007) >> 0);
+	  break;
+	default:
+	  DISSECTOR_ASSERT_NOT_REACHED();
       }
       break;
     case ANSI_STANDARD:
@@ -250,24 +263,24 @@ mtp3_pc_to_str_buf(const guint32 pc, gchar *buf, int buf_len)
       break;
     case JAPAN_STANDARD:
       switch (japan_pc_structure) {
-        case JAPAN_PC_STRUCTURE_NONE:
+	case JAPAN_PC_STRUCTURE_NONE:
 	  g_snprintf(buf, buf_len, "%u", pc);
 	  break;
-        case JAPAN_PC_STRUCTURE_7_4_5:
+	case JAPAN_PC_STRUCTURE_7_4_5:
 	  /* This format is specified by NTT */
 	  g_snprintf(buf, buf_len, "%u-%u-%u", (pc & 0xfe00)>>9, (pc & 0x1e0)>>5, (pc & 0x1f));
 	  break;
-        case JAPAN_PC_STRUCTURE_3_4_4_5:
+	case JAPAN_PC_STRUCTURE_3_4_4_5:
 	  /* Where does this format come from? */
 	  g_snprintf(buf, buf_len, "%u-%u-%u-%u", (pc & 0xe000)>>13, (pc & 0x1e00)>>9, (pc & 0x1e0)>>5, (pc & 0x1f));
 	  break;
-        default:
-          DISSECTOR_ASSERT_NOT_REACHED();
+	default:
+	  DISSECTOR_ASSERT_NOT_REACHED();
       }
       break;
     default:
       DISSECTOR_ASSERT_NOT_REACHED();
-  }
+    }
 }
 
 #define MAX_STRUCTURED_PC_LENGTH 20
@@ -298,10 +311,8 @@ mtp3_pc_structured(void)
  */
 
 void
-mtp3_addr_to_str_buf(
-  const mtp3_addr_pc_t  *addr_pc_p,
-  gchar                 *buf,
-  int                   buf_len)
+mtp3_addr_to_str_buf(const mtp3_addr_pc_t  *addr_pc_p,
+		     gchar *buf, int buf_len)
 {
   switch (mtp3_addr_fmt)
   {
@@ -378,21 +389,22 @@ mtp3_addr_to_str_buf(
   }
 }
 
-guint32 mtp3_pc_hash(const mtp3_addr_pc_t *addr_pc_p) {
-	guint32 pc;
+guint32
+mtp3_pc_hash(const mtp3_addr_pc_t *addr_pc_p) {
+    guint32 pc;
 
-	switch (addr_pc_p->type)
-	{
-		case ITU_STANDARD:
-			pc = (addr_pc_p->pc & ITU_PC_MASK) | ((addr_pc_p->ni % 4) << 14) ;
-			break;
-		default:
-			/* assuming 24-bit */
-			pc = (addr_pc_p->pc & ANSI_PC_MASK) | ((addr_pc_p->ni) << 24) ;
-			break;
-	}
+    switch (addr_pc_p->type)
+    {
+	case ITU_STANDARD:
+	    pc = (addr_pc_p->pc & ITU_PC_MASK) | ((addr_pc_p->ni % 4) << 14) ;
+	    break;
+	default:
+	    /* assuming 24-bit */
+	    pc = (addr_pc_p->pc & ANSI_PC_MASK) | ((addr_pc_p->ni) << 24) ;
+	    break;
+    }
 
-	return pc;
+    return pc;
 }
 
 /*  Common function for dissecting 3-byte (ANSI or China) PCs. */
@@ -562,9 +574,9 @@ dissect_mtp3_routing_label(tvbuff_t *tvb, packet_info *pinfo, proto_tree *mtp3_t
     /* SLS */
     if (mtp3_standard == ANSI_STANDARD) {
       if (mtp3_use_ansi_5_bit_sls)
-        proto_tree_add_item(label_tree, hf_mtp3_ansi_5_bit_sls, tvb, ANSI_SLS_OFFSET, SLS_LENGTH, ENC_NA);
+	proto_tree_add_item(label_tree, hf_mtp3_ansi_5_bit_sls, tvb, ANSI_SLS_OFFSET, SLS_LENGTH, ENC_NA);
       else
-        proto_tree_add_item(label_tree, hf_mtp3_ansi_8_bit_sls, tvb, ANSI_SLS_OFFSET, SLS_LENGTH, ENC_NA);
+	proto_tree_add_item(label_tree, hf_mtp3_ansi_8_bit_sls, tvb, ANSI_SLS_OFFSET, SLS_LENGTH, ENC_NA);
     } else /* CHINESE_ITU_STANDARD */ {
       proto_tree_add_item(label_tree, hf_mtp3_chinese_itu_sls, tvb, ANSI_SLS_OFFSET, SLS_LENGTH, ENC_NA);
     }
@@ -644,69 +656,129 @@ dissect_mtp3_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     call_dissector(data_handle, payload_tvb, pinfo, tree);
 }
 
+#define HEURISTIC_FAILED_STANDARD 0xffff
+static guint
+heur_mtp3_standard(tvbuff_t *tvb, packet_info *pinfo, guint8 si)
+{
+
+    guint32 len;
+    tvbuff_t *payload;
+
+    len = tvb_length(tvb);
+    switch (si) {
+    case MTP_SI_SCCP:
+	{
+	    payload = tvb_new_subset(tvb, ITU_HEADER_LENGTH, len-ITU_HEADER_LENGTH, len-ITU_HEADER_LENGTH);
+	    if (looks_like_valid_sccp(PINFO_FD_NUM(pinfo), payload, ITU_STANDARD)) {
+		return ITU_STANDARD;
+	    }
+	    payload = tvb_new_subset(tvb, ANSI_HEADER_LENGTH, len-ANSI_HEADER_LENGTH, len-ANSI_HEADER_LENGTH);
+	    if (looks_like_valid_sccp(PINFO_FD_NUM(pinfo), payload, ANSI_STANDARD)) {
+		return ANSI_STANDARD;
+	    }
+	    payload = tvb_new_subset(tvb, ANSI_HEADER_LENGTH, len-ANSI_HEADER_LENGTH, len-ANSI_HEADER_LENGTH);
+	    if (looks_like_valid_sccp(PINFO_FD_NUM(pinfo), payload, CHINESE_ITU_STANDARD)) {
+		return CHINESE_ITU_STANDARD;
+	    }
+	    payload = tvb_new_subset(tvb, JAPAN_HEADER_LENGTH, len-JAPAN_HEADER_LENGTH, len-JAPAN_HEADER_LENGTH);
+	    if (looks_like_valid_sccp(PINFO_FD_NUM(pinfo), payload, JAPAN_STANDARD)) {
+		return JAPAN_STANDARD;
+	    }
+
+	    return HEURISTIC_FAILED_STANDARD;
+
+	}
+    default:
+	return HEURISTIC_FAILED_STANDARD;
+    }
+
+}
+
+static void
+reset_mtp3_standard(void)
+{
+    mtp3_standard = pref_mtp3_standard;
+}
+
 /* Code to actually dissect the packets */
 static void
 dissect_mtp3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-  void* pd_save;
-  mtp3_tap_rec_t* tap_rec = ep_alloc0(sizeof(mtp3_tap_rec_t));
+    void* pd_save;
+    mtp3_tap_rec_t* tap_rec = ep_alloc0(sizeof(mtp3_tap_rec_t));
+    gint heuristic_standard;
+    guint8 si;
 
-  /* Set up structures needed to add the protocol subtree and manage it */
-  proto_item *mtp3_item = NULL;
-  proto_tree *mtp3_tree = NULL;
+    /* Set up structures needed to add the protocol subtree and manage it */
+    proto_item *mtp3_item = NULL, *gen_item;
+    proto_tree *mtp3_tree = NULL;
 
-  /* Make entries in Protocol column on summary display */
-  switch(mtp3_standard) {
+    pref_mtp3_standard = mtp3_standard;
+
+    mtp3_item = proto_tree_add_item(tree, proto_mtp3, tvb, 0, 0, ENC_NA);
+
+    si = tvb_get_guint8(tvb, SIO_OFFSET) & SERVICE_INDICATOR_MASK;
+    if (mtp3_heuristic_standard) {
+	heuristic_standard = heur_mtp3_standard(tvb, pinfo, si);
+	if (heuristic_standard == HEURISTIC_FAILED_STANDARD) {
+	    gen_item = proto_tree_add_text(tree, tvb, 0, 0, "Could not determine Heuristic using %s", val_to_str(mtp3_standard, mtp3_standard_vals, "unknown"));
+	} else {
+	    gen_item = proto_tree_add_text(tree, tvb, 0, 0, "%s", val_to_str(heuristic_standard, mtp3_standard_vals, "unknown"));
+	    mtp3_standard = heuristic_standard;
+
+	    /* Register a frame-end routine to ensure mtp3_standard is set
+	     * back, even if an exception is thrown.
+	     */
+	    register_frame_end_routine(reset_mtp3_standard);
+	}
+	PROTO_ITEM_SET_GENERATED(gen_item);
+    }
+
+    /* Make entries in Protocol column on summary display */
+    switch(mtp3_standard) {
     case ITU_STANDARD:
-      col_set_str(pinfo->cinfo, COL_PROTOCOL, "MTP3 (Int. ITU)");
-      break;
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "MTP3 (Int. ITU)");
+	proto_item_set_len(mtp3_item, ITU_HEADER_LENGTH);
+	break;
     case ANSI_STANDARD:
-      col_set_str(pinfo->cinfo, COL_PROTOCOL, "MTP3 (ANSI)");
-      break;
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "MTP3 (ANSI)");
+	proto_item_set_len(mtp3_item, ANSI_HEADER_LENGTH);
+	break;
     case CHINESE_ITU_STANDARD:
-      col_set_str(pinfo->cinfo, COL_PROTOCOL, "MTP3 (Chin. ITU)");
-      break;
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "MTP3 (Chin. ITU)");
+	proto_item_set_len(mtp3_item, ANSI_HEADER_LENGTH);
+	break;
     case JAPAN_STANDARD:
-      col_set_str(pinfo->cinfo, COL_PROTOCOL, "MTP3 (Japan)");
-      break;
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "MTP3 (Japan)");
+	proto_item_set_len(mtp3_item, JAPAN_HEADER_LENGTH);
+	break;
     };
 
-  if (tree) {
-    /* create display subtree for the protocol */
-    switch (mtp3_standard) {
-    case ITU_STANDARD:
-      mtp3_item = proto_tree_add_item(tree, proto_mtp3, tvb, 0, ITU_HEADER_LENGTH, ENC_NA);
-      break;
-    case ANSI_STANDARD:
-    case CHINESE_ITU_STANDARD:
-      mtp3_item = proto_tree_add_item(tree, proto_mtp3, tvb, 0, ANSI_HEADER_LENGTH, ENC_NA);
-      break;
-    case JAPAN_STANDARD:
-      mtp3_item = proto_tree_add_item(tree, proto_mtp3, tvb, 0, JAPAN_HEADER_LENGTH, ENC_NA);
-      break;
+    if (tree) {
+	/* create display subtree for the protocol */
+	mtp3_tree = proto_item_add_subtree(mtp3_item, ett_mtp3);
     }
-    mtp3_tree = proto_item_add_subtree(mtp3_item, ett_mtp3);
 
-  }
+    mtp3_addr_opc = ep_alloc0(sizeof(mtp3_addr_pc_t));
+    mtp3_addr_dpc = ep_alloc0(sizeof(mtp3_addr_pc_t));
 
-  mtp3_addr_opc = ep_alloc0(sizeof(mtp3_addr_pc_t));
-  mtp3_addr_dpc = ep_alloc0(sizeof(mtp3_addr_pc_t));
+    /* Dissect the packet (even if !tree so can call sub-dissectors and update
+     * the source and destination address columns) */
+    dissect_mtp3_sio(tvb, pinfo, mtp3_tree, &pd_save);
+    dissect_mtp3_routing_label(tvb, pinfo, mtp3_tree);
 
-  /* Dissect the packet (even if !tree so can call sub-dissectors and update
-   * the source and destination address columns) */
-  dissect_mtp3_sio(tvb, pinfo, mtp3_tree, &pd_save);
-  dissect_mtp3_routing_label(tvb, pinfo, mtp3_tree);
+    memcpy(&(tap_rec->addr_opc), mtp3_addr_opc, sizeof(mtp3_addr_pc_t));
+    memcpy(&(tap_rec->addr_dpc), mtp3_addr_dpc, sizeof(mtp3_addr_pc_t));
 
-  memcpy(&(tap_rec->addr_opc),mtp3_addr_opc,sizeof(mtp3_addr_pc_t));
-  memcpy(&(tap_rec->addr_dpc),mtp3_addr_dpc,sizeof(mtp3_addr_pc_t));
+    tap_rec->si_code = (tvb_get_guint8(tvb, SIO_OFFSET) & SERVICE_INDICATOR_MASK);
+    tap_rec->size = tvb_length(tvb);
 
-  tap_rec->si_code = (tvb_get_guint8(tvb, SIO_OFFSET) & SERVICE_INDICATOR_MASK);
-  tap_rec->size = tvb_length(tvb);
+    tap_queue_packet(mtp3_tap, pinfo, tap_rec);
 
-  tap_queue_packet(mtp3_tap, pinfo, tap_rec);
+    dissect_mtp3_payload(tvb, pinfo, tree);
+    pinfo->private_data = pd_save;
 
-  dissect_mtp3_payload(tvb, pinfo, tree);
-  pinfo->private_data = pd_save;
+    mtp3_standard = pref_mtp3_standard;
 }
 
 void
@@ -759,39 +831,39 @@ proto_register_mtp3(void)
   };
 
   static enum_val_t mtp3_options[] = {
-    { "itu",         "ITU",         ITU_STANDARD },
-    { "ansi",        "ANSI",        ANSI_STANDARD },
-    { "chinese-itu", "Chinese ITU", CHINESE_ITU_STANDARD },
-    { "japan",       "Japan",       JAPAN_STANDARD },
+    { "itu",		"ITU",		ITU_STANDARD },
+    { "ansi",		"ANSI",		ANSI_STANDARD },
+    { "chinese-itu",	"Chinese ITU",	CHINESE_ITU_STANDARD },
+    { "japan",		"Japan",	JAPAN_STANDARD },
     { NULL, NULL, 0 }
   };
 
   static enum_val_t mtp3_addr_fmt_str_e[] = {
-    { "decimal",        "Decimal",              MTP3_ADDR_FMT_DEC },
-    { "hexadecimal",    "Hexadecimal",          MTP3_ADDR_FMT_HEX },
-    { "ni-decimal",     "NI-Decimal",           MTP3_ADDR_FMT_NI_DEC },
+    { "decimal",	"Decimal",		MTP3_ADDR_FMT_DEC },
+    { "hexadecimal",	"Hexadecimal",		MTP3_ADDR_FMT_HEX },
+    { "ni-decimal",     "NI-Decimal",		MTP3_ADDR_FMT_NI_DEC },
     { "ni-hexadecimal", "NI-Hexadecimal",       MTP3_ADDR_FMT_NI_HEX },
-    { "dashed",         "Dashed",               MTP3_ADDR_FMT_DASHED },
-    { NULL,             NULL,                   0 }
+    { "dashed",		"Dashed",		MTP3_ADDR_FMT_DASHED },
+    { NULL,		NULL,			0 }
   };
 
   static enum_val_t itu_pc_structures[] = {
-    { "unstructured", "Unstructured", ITU_PC_STRUCTURE_NONE},
-    { "3-8-3",        "3-8-3",        ITU_PC_STRUCTURE_3_8_3 },
-    { "4-3-4-3",      "4-3-4-3",      ITU_PC_STRUCTURE_4_3_4_3 },
-    { NULL,           NULL,           0 }
+    { "unstructured",	"Unstructured",	ITU_PC_STRUCTURE_NONE},
+    { "3-8-3",		"3-8-3",	ITU_PC_STRUCTURE_3_8_3 },
+    { "4-3-4-3",	"4-3-4-3",	ITU_PC_STRUCTURE_4_3_4_3 },
+    { NULL,		NULL,		0 }
   };
 
   static enum_val_t japan_pc_structures[] = {
-    { "unstructured", "Unstructured", JAPAN_PC_STRUCTURE_NONE},
-    { "7-4-5",        "7-4-5",        JAPAN_PC_STRUCTURE_7_4_5 },
-    { "3-4-4-5",      "3-4-4-5",      JAPAN_PC_STRUCTURE_3_4_4_5 },
-    { NULL,           NULL,           0 }
+    { "unstructured",	"Unstructured",	JAPAN_PC_STRUCTURE_NONE},
+    { "7-4-5",		"7-4-5",	JAPAN_PC_STRUCTURE_7_4_5 },
+    { "3-4-4-5",	"3-4-4-5",	JAPAN_PC_STRUCTURE_3_4_4_5 },
+    { NULL,		NULL,		0 }
   };
 
  /* Register the protocol name and description */
   proto_mtp3 = proto_register_protocol("Message Transfer Part Level 3",
-                                       "MTP3", "mtp3");
+				       "MTP3", "mtp3");
   register_dissector("mtp3", dissect_mtp3, proto_mtp3);
 
   /* Required function calls to register the header fields and subtrees used */
@@ -799,43 +871,48 @@ proto_register_mtp3(void)
   proto_register_subtree_array(ett, array_length(ett));
 
   mtp3_sio_dissector_table = register_dissector_table("mtp3.service_indicator",
-                                                      "MTP3 Service indicator",
-                                                      FT_UINT8, BASE_HEX);
+						      "MTP3 Service indicator",
+						      FT_UINT8, BASE_HEX);
 
   mtp3_tap = register_tap("mtp3");
 
   mtp3_module = prefs_register_protocol(proto_mtp3, NULL);
 
+  prefs_register_bool_preference(mtp3_module, "heuristic_standard",
+				 "Try to determine the MTP3 standard heuristically",
+				 "This only works for SCCP traffic for now",
+				 &mtp3_heuristic_standard);
+
   prefs_register_enum_preference(mtp3_module, "standard", "MTP3 standard",
-                                 "The SS7 standard used in MTP3 packets",
-                                 &mtp3_standard, mtp3_options, FALSE);
+				 "The SS7 standard used in MTP3 packets",
+				 &mtp3_standard, mtp3_options, FALSE);
 
   prefs_register_enum_preference(mtp3_module, "itu_pc_structure", "ITU Pointcode structure",
-                                 "The structure of the pointcodes in ITU networks",
-                                 &itu_pc_structure, itu_pc_structures, FALSE);
+				 "The structure of the pointcodes in ITU networks",
+				 &itu_pc_structure, itu_pc_structures, FALSE);
 
   prefs_register_enum_preference(mtp3_module, "japan_pc_structure", "Japan Pointcode structure",
-                                 "The structure of the pointcodes in Japan networks",
-                                 &japan_pc_structure, japan_pc_structures, FALSE);
+				 "The structure of the pointcodes in Japan networks",
+				 &japan_pc_structure, japan_pc_structures, FALSE);
 
   prefs_register_bool_preference(mtp3_module, "ansi_5_bit_sls",
-                                 "Use 5-bit SLS (ANSI only)",
-                                 "Use 5-bit (instead of 8-bit) SLS in ANSI MTP3 packets",
-                                 &mtp3_use_ansi_5_bit_sls);
+				 "Use 5-bit SLS (ANSI only)",
+				 "Use 5-bit (instead of 8-bit) SLS in ANSI MTP3 packets",
+				 &mtp3_use_ansi_5_bit_sls);
 
   prefs_register_bool_preference(mtp3_module, "japan_5_bit_sls",
-                                 "Use 5-bit SLS (Japan only)",
-                                 "Use 5-bit (instead of 4-bit) SLS in Japan MTP3 packets",
-                                 &mtp3_use_japan_5_bit_sls);
+				 "Use 5-bit SLS (Japan only)",
+				 "Use 5-bit (instead of 4-bit) SLS in Japan MTP3 packets",
+				 &mtp3_use_japan_5_bit_sls);
 
   prefs_register_enum_preference(mtp3_module, "addr_format", "Address Format",
-                                 "Format for point code in the address columns",
-                                 &mtp3_addr_fmt, mtp3_addr_fmt_str_e, FALSE);
+				 "Format for point code in the address columns",
+				 &mtp3_addr_fmt, mtp3_addr_fmt_str_e, FALSE);
 
   prefs_register_bool_preference(mtp3_module, "itu_priority",
-                                 "Show MSU priority (national option, ITU and China ITU only)",
-                                 "Decode the spare bits of the SIO as the MSU priority (a national option in ITU)",
-                                 &mtp3_show_itu_priority);
+				 "Show MSU priority (national option, ITU and China ITU only)",
+				 "Decode the spare bits of the SIO as the MSU priority (a national option in ITU)",
+				 &mtp3_show_itu_priority);
 
 }
 
