@@ -1,9 +1,9 @@
 /* packet-retix-bpdu.c
  * Routines for BPDU (Retix Spanning Tree Protocol) disassembly
  *
- * $Id: packet-retix-bpdu.c 32410 2010-04-06 21:14:01Z wmeier $
+ * $Id: packet-retix-bpdu.c 39503 2011-10-21 02:10:19Z wmeier $
  *
- * Copyright 2005 Giles Scott (gscott <AT> arubanetworks dot com> 
+ * Copyright 2005 Giles Scott (gscott <AT> arubanetworks dot com>
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -61,30 +61,28 @@ dissect_retix_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
   proto_tree *retix_bpdu_tree;
   proto_tree *ti;
-  const guint8 *bridge_mac_str;
 
   col_set_str(pinfo->cinfo, COL_PROTOCOL, "R-STP");
   col_clear(pinfo->cinfo, COL_INFO);
-  bridge_mac_str = tvb_get_ptr(tvb, 10, 6);
   if (check_col(pinfo->cinfo, COL_INFO)){
-    col_add_fstr(pinfo->cinfo, COL_INFO, "Bridge MAC %s", ether_to_str(bridge_mac_str)); 
+    col_add_fstr(pinfo->cinfo, COL_INFO, "Bridge MAC %s", tvb_ether_to_str(tvb, 10));
   }
 
-  
+
   retix_bpdu_tree = NULL;
 
   if (tree) {
-    ti = proto_tree_add_item(tree, proto_retix_bpdu, tvb, 0, -1, FALSE);
+    ti = proto_tree_add_item(tree, proto_retix_bpdu, tvb, 0, -1, ENC_NA);
     retix_bpdu_tree = proto_item_add_subtree(ti, ett_retix_bpdu);
   }
 
-  proto_tree_add_item(retix_bpdu_tree, hf_retix_bpdu_root_mac, tvb, 0, 6, FALSE);
+  proto_tree_add_item(retix_bpdu_tree, hf_retix_bpdu_root_mac, tvb, 0, 6, ENC_NA);
 
-  proto_tree_add_item(retix_bpdu_tree, hf_retix_bpdu_bridge_mac, tvb, 10, 6, FALSE);
+  proto_tree_add_item(retix_bpdu_tree, hf_retix_bpdu_bridge_mac, tvb, 10, 6, ENC_NA);
 
-  proto_tree_add_item(retix_bpdu_tree, hf_retix_bpdu_max_age, tvb, 20, 2, FALSE);
-  proto_tree_add_item(retix_bpdu_tree, hf_retix_bpdu_hello_time, tvb, 22, 2, FALSE);
-  proto_tree_add_item(retix_bpdu_tree, hf_retix_bpdu_forward_delay, tvb, 24, 2, FALSE);
+  proto_tree_add_item(retix_bpdu_tree, hf_retix_bpdu_max_age, tvb, 20, 2, ENC_BIG_ENDIAN);
+  proto_tree_add_item(retix_bpdu_tree, hf_retix_bpdu_hello_time, tvb, 22, 2, ENC_BIG_ENDIAN);
+  proto_tree_add_item(retix_bpdu_tree, hf_retix_bpdu_forward_delay, tvb, 24, 2, ENC_BIG_ENDIAN);
 
 }
 
@@ -119,7 +117,7 @@ proto_register_retix_bpdu(void)
   };
 
   proto_retix_bpdu = proto_register_protocol("Retix Spanning Tree Protocol", "R-STP", "r-stp");
-  proto_register_field_array(proto_retix_bpdu, hf, array_length(hf)); 
+  proto_register_field_array(proto_retix_bpdu, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
   register_dissector("rbpdu", dissect_retix_bpdu, proto_retix_bpdu);
 }
