@@ -1,7 +1,7 @@
 /* Routines for UMTS RLC (Radio Link Control) disassembly
  * http://www.3gpp.org/ftp/Specs/archive/25_series/25.322/
  *
- * $Id: packet-rlc.c 42889 2012-05-28 20:34:27Z pascal $
+ * $Id: packet-rlc.c 50845 2013-07-23 18:09:22Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1905,7 +1905,7 @@ dissect_rlc_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	   - conditional header bytes
 	   - tag for data
 	   - at least one byte of RLC PDU payload */
-	if ((size_t)tvb_length_remaining(tvb, offset) < (strlen(RLC_START_STRING)+2+2)) {
+    if (tvb_length_remaining(tvb, offset) < (gint)(strlen(RLC_START_STRING)+2+2)) {
 		return FALSE;
 	}
 
