@@ -2,7 +2,7 @@
 *
 * Routine to dissect ISO 8327-1 OSI Session Protocol packets
 *
-* $Id: packet-ses.h 33208 2010-06-11 09:14:25Z stig $
+* $Id: packet-ses.h 40595 2012-01-19 22:55:37Z rbalint $
 *
 * Yuriy Sidelnikov <YSidelnikov@hotmail.com>
 *
@@ -25,6 +25,8 @@
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
+#ifndef PACKET_SES_H
+#define PACKET_SES_H
 
 #define PROTO_STRING_SES "ISO 8327-1 OSI Session Protocol"
 #define PROTO_STRING_SES_INFO "ISO 8327-1 OSI Session Protocol."
@@ -207,3 +209,4 @@ struct SESSION_DATA_STRUCTURE
 
 extern const value_string ses_vals[];
 
+#endif
