@@ -2,7 +2,7 @@
  * Routines for SMB Browser packet dissection
  * Copyright 1999, Richard Sharpe <rsharpe@ns.aus.com>
  *
- * $Id: packet-smb-browse.c 39514 2011-10-23 17:11:39Z wmeier $
+ * $Id: packet-smb-browse.c 42634 2012-05-15 20:57:21Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,12 +29,12 @@
 # include "config.h"
 #endif
 
-#include <time.h>
+#include <string.h>
+
 #include <glib.h>
-#include <ctype.h>
+
 #include <epan/packet.h>
 #include <epan/dissectors/packet-smb.h>
-#include <string.h>
 
 #include "packet-smb-browse.h"
 #include "packet-dcerpc.h"
@@ -587,7 +587,7 @@ dissect_mailslot_browse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tr
 	gint namelen;
 	guint8 server_count, reset_cmd;
 	guint8 os_major_ver, os_minor_ver;
-	gchar *windows_version = NULL;
+	const gchar *windows_version = NULL;
 	int i;
 	guint32 uptime;
 
@@ -846,7 +846,7 @@ dissect_mailslot_lanman(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tr
 	guint32 periodicity;
 	const guint8 *host_name;
 	guint8 os_major_ver, os_minor_ver;
-	gchar *windows_version = NULL;
+	const gchar *windows_version = NULL;
 	guint namelen;
 
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "BROWSER");
