@@ -2,7 +2,7 @@
  * Allow users to specify the dissectors for DLTs
  * Luis E. Garcia Ontanon <luis@ontanon.org>
  *
- * $Id: packet-user_encap.c 47325 2013-01-28 18:02:58Z gerald $
+ * $Id: packet-user_encap.c 49814 2013-06-06 19:14:23Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -82,7 +82,7 @@ static void dissect_user(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree) {
     user_encap_t* encap = NULL;
     tvbuff_t* payload_tvb;
     proto_item* item;
-    int len;
+    gint len, reported_len;
     guint i;
 
     for (i = 0; i < num_encaps; i++) {
@@ -117,8 +117,6 @@ static void dissect_user(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree) {
 
     proto_item_set_text(item,"DLT: %d",pinfo->match_uint + 147 - WTAP_ENCAP_USER0);
 
-    len = tvb_reported_length(tvb) - (encap->header_size + encap->trailer_size);
-
     if (encap->header_size) {
         tvbuff_t* hdr_tvb = tvb_new_subset(tvb, 0, encap->header_size, encap->header_size);
         call_dissector(encap->header_proto, hdr_tvb, pinfo, tree);
@@ -130,7 +128,10 @@ static void dissect_user(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree) {
         }
     }
 
-    payload_tvb = tvb_new_subset(tvb, encap->header_size, len, len);
+    len = tvb_length(tvb) - (encap->header_size + encap->trailer_size);
+    reported_len = tvb_reported_length(tvb) - (encap->header_size + encap->trailer_size);
+
+    payload_tvb = tvb_new_subset(tvb, encap->header_size, len, reported_len);
     call_dissector(encap->payload_proto, payload_tvb, pinfo, tree);
     if (encap->payload_proto_name) {
         const char *proto_name = dissector_handle_get_long_name(find_dissector(encap->payload_proto_name));
