@@ -3,7 +3,7 @@
  *
  * Implemented as a tap named "expert".
  *
- * $Id: expert.c 49814 2013-06-06 19:14:23Z gerald $
+ * $Id: expert.c 50870 2013-07-24 17:47:39Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -39,6 +39,8 @@
  */
 int proto_expert              = -1;
 
+static int proto_malformed    = -1;
+
 static int expert_tap         = -1;
 static int highest_severity   =  0;
 
@@ -105,6 +107,8 @@ expert_init(void)
 	}
 
 	highest_severity = 0;
+
+	proto_malformed = proto_get_id_by_filter_name("malformed");
 }
 
 
@@ -149,7 +153,6 @@ expert_create_tree(proto_item *pi, int group, int severity, const char *msg)
 
 	if (group == PI_MALFORMED) {
 		/* Add hidden malformed protocol filter */
-		gint proto_malformed = proto_get_id_by_filter_name("malformed");
 		proto_item *malformed_ti = proto_tree_add_item(tree, proto_malformed, NULL, 0, 0, ENC_NA);
 		PROTO_ITEM_SET_HIDDEN(malformed_ti);
 	}
