@@ -6,7 +6,7 @@
  * (c) 2006, Luis E. Garcia Ontanon <luis@ontanon.org>
  * (c) 2007, Tamas Regos <tamas.regos@ericsson.com>
  *
- * $Id: wslua_proto.c 46303 2012-11-30 11:02:46Z stig $
+ * $Id: wslua_proto.c 50870 2013-07-24 17:47:39Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -661,7 +661,7 @@ WSLUA_CONSTRUCTOR ProtoField_new(lua_State* L) { /* Creates a new field to be us
 
     /* XXX: need BASE_ERROR */
     f->base = string_to_base(luaL_optstring(L, WSLUA_OPTARG_ProtoField_new_BASE, "BASE_NONE"));
-    f->mask = luaL_optint(L, WSLUA_OPTARG_ProtoField_new_MASK, 0x0);
+    f->mask = (guint32)luaL_optnumber(L, WSLUA_OPTARG_ProtoField_new_MASK, 0x0);
     blob = luaL_optstring(L,WSLUA_OPTARG_ProtoField_new_DESCR,NULL);
     if (blob && strcmp(blob, f->name) != 0) {
         f->blob = g_strdup(blob);
@@ -680,7 +680,7 @@ static int ProtoField_integer(lua_State* L, enum ftenum type) {
     const gchar* name = luaL_optstring(L,2,abbr);
     base_display_e base = luaL_optint(L, 3, BASE_DEC);
     value_string* vs = (lua_gettop(L) > 3) ? value_string_from_table(L,4) : NULL;
-    guint32 mask = luaL_optint(L, 5, 0x0);
+    guint32 mask = (guint32)luaL_optnumber(L,5,0);
     const gchar* blob = luaL_optstring(L,6,NULL);
 
     if (type == FT_FRAMENUM) {
@@ -850,7 +850,7 @@ static int ProtoField_boolean(lua_State* L, enum ftenum type) {
     const gchar* name = luaL_optstring(L,2,abbr);
     base_display_e base = luaL_optint(L, 3, BASE_NONE);
     true_false_string* tfs = (lua_gettop(L) > 3) ? true_false_string_from_table(L,4) : NULL;
-    int mask = luaL_optint(L, 5, 0x0);
+    guint32 mask = (guint32)luaL_optnumber(L,5,0);
     const gchar* blob = luaL_optstring(L,6,NULL);
 
     if (mask == 0x0 && base != BASE_NONE) {
