@@ -1,7 +1,7 @@
 /* fileset.h
  * Definitions for routines for file sets.
  *
- * $Id: fileset.h 28108 2009-04-21 16:57:52Z guy $
+ * $Id: fileset.h 45188 2012-09-28 09:48:55Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef __FILESET_H__
@@ -31,12 +31,12 @@ extern "C" {
 
 
 typedef struct _fileset_entry {
-  const char    *fullname;      /* File name with path (g_strdup'ed) */
-  const char    *name;          /* File name without path (g_strdup'ed) */
-  time_t        ctime;          /* create time */
-  time_t        mtime;          /* last modified time */
-  gint64        size;           /* size of file in bytes */
-  gboolean      current;        /* is this the currently loaded file? */
+  char     *fullname;      /* File name with path (g_strdup'ed) */
+  char     *name;          /* File name without path (g_strdup'ed) */
+  time_t   ctime;          /* create time */
+  time_t   mtime;          /* last modified time */
+  gint64   size;           /* size of file in bytes */
+  gboolean current;        /* is this the currently loaded file? */
 } fileset_entry;
 
 
@@ -67,6 +67,8 @@ extern void fileset_file_closed(void);
 
 extern void fileset_update_dlg(void);
 
+extern void fileset_update_file(const char *path);
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
