@@ -1,7 +1,7 @@
 /* merge.h
  * Definitions for routines for merging files.
  *
- * $Id: merge.h 39949 2011-11-19 20:18:01Z guy $
+ * $Id: merge.h 45204 2012-09-28 23:54:02Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -44,8 +44,10 @@ typedef struct merge_in_file_s {
   wtap           *wth;
   gint64          data_offset;
   in_file_state_e state;
-  guint32         packet_num;	/* current packet number */
-  gint64          size;		/* file size */
+  guint32         packet_num;	  /* current packet number */
+  gint64          size;		      /* file size */
+  guint32         interface_id;   /* identifier of the interface. 
+								   * Used for fake interfaces when writing WTAP_ENCAP_PER_PACKET */
 } merge_in_file_t;
 
 /** Open a number of input files to merge.
