@@ -2,7 +2,7 @@
  * H.225 message counter for Wireshark
  * Copyright 2003 Lars Roland
  *
- * $Id: h225_counter.c 40529 2012-01-16 01:07:52Z guy $
+ * $Id: h225_counter.c 42443 2012-05-05 20:51:14Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,10 +27,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <string.h>
 
 #include <gtk/gtk.h>
@@ -534,7 +530,7 @@ gtk_h225counter_init(const char *optarg, void *userdata _U_)
 
 	gtk_window_set_default_size(GTK_WINDOW(hs->win), 400, 200);
 
-	hs->vbox=gtk_vbox_new(FALSE, 3);
+	hs->vbox=ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
 	gtk_container_set_border_width(GTK_CONTAINER(hs->vbox), 12);
 
 	init_main_stat_window(hs->win, hs->vbox, "H.225 Message and Message Reason Counter", hs->filter);
