@@ -1,6 +1,6 @@
 /* main_welcome.c
  *
- * $Id: main_welcome.c 43122 2012-06-05 16:46:30Z gerald $
+ * $Id: main_welcome.c 45173 2012-09-27 13:14:04Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1215,7 +1215,6 @@ welcome_new(void)
     GtkWidget *file_child_box;
 #ifdef _WIN32
     DWORD chimney_enabled = 0;
-    DWORD ce_size = sizeof(chimney_enabled);
 #endif
     /* prepare colors */
 #if 0
