@@ -3,7 +3,7 @@
  * Copyright 2008-2009, Stephen Fisher (see AUTHORS file)
  * Co-authors Anders Broman, Kovarththanan Rajaratnam and Stig Bjorlykke.
  *
- * $Id: new_packet_list.c 41895 2012-04-02 15:20:54Z etxrab $
+ * $Id: new_packet_list.c 43393 2012-06-20 01:13:06Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -335,7 +335,7 @@ col_details_edit_dlg (gint col_id, GtkTreeViewColumn *col)
 	gtk_window_set_resizable(GTK_WINDOW(win),FALSE);
 	gtk_window_resize(GTK_WINDOW(win), 400, 100);
 
-	main_vb = gtk_vbox_new(FALSE, 6);
+	main_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
 	gtk_container_add(GTK_CONTAINER(win), main_vb);
 	gtk_container_set_border_width(GTK_CONTAINER(main_vb), 6);
 
@@ -1118,7 +1118,7 @@ new_packet_list_check_end(void)
 	}
 #ifdef HAVE_LIBPCAP
 	if (gtk_adjustment_get_value(adj) > 0 && at_end != last_at_end && at_end != auto_scroll_live) {
-		menu_auto_scroll_live_changed(at_end);
+		main_auto_scroll_live_changed(at_end);
 	}
 #endif
 	last_at_end = at_end;
@@ -1450,7 +1450,6 @@ new_packet_list_set_font(PangoFontDescription *font)
 static void
 mark_frames_ready(void)
 {
-	file_save_update_dynamics();
 	packets_bar_update();
 	new_packet_list_queue_draw();
 }
@@ -1749,12 +1748,10 @@ new_packet_list_update_packet_comment(gchar *new_packet_comment)
 	}
 
 	/* The comment has changed, let's update it */
-	g_free(record->fdata->opt_comment);
-	record->fdata->opt_comment = new_packet_comment;
+	cf_update_packet_comment(&cfile, record->fdata, new_packet_comment);
 
-	/* Mark the file as unsaved */
-	cfile.user_saved = FALSE;
-	set_menus_for_capture_file(&cfile);
+	/* Update the main window, as we now have unsaved changes. */
+	main_update_for_unsaved_changes(&cfile);
 
 	new_packet_list_queue_draw();
 
