@@ -1,6 +1,6 @@
 /* file_access.c
  *
- * $Id: file_access.c 46775 2012-12-26 12:05:02Z guy $
+ * $Id: file_access.c 49337 2013-05-16 18:29:20Z pascal $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -128,15 +128,14 @@ static wtap_open_routine_t open_routines_base[] = {
 	dbs_etherwatch_open,
 	k12_open,
 	catapult_dct2000_open,
-	ber_open,
+	ber_open,          /* XXX - this is really a heuristic */
 	aethra_open,
 	btsnoop_open,
 	eyesdn_open,
-	vwr_open,
+	vwr_open,          /* XXX - this is really a heuristic */
 	packetlogger_open, /* This type does not have a magic number, but its
 			    * files are sometimes grabbed by mpeg_open. */
 	mpeg_open,
-	mp2t_open,
 	tnef_open,
 	dct3trace_open,
 	daintree_sna_open,
@@ -161,6 +160,7 @@ static wtap_open_routine_t open_routines_base[] = {
 	ascend_open,
 	toshiba_open,
 	i4btrace_open,
+	mp2t_open,
 	csids_open,
 	vms_open,
 	cosine_open,
