@@ -1,6 +1,6 @@
 /* netmon.c
  *
- * $Id: netmon.c 42998 2012-06-02 14:13:14Z etxrab $
+ * $Id: netmon.c 50684 2013-07-16 23:19:54Z gerald $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -306,6 +306,15 @@ int netmon_open(wtap *wth, int *err, gchar **err_info)
 	netmon->version_major = hdr.ver_major;
 	netmon->version_minor = hdr.ver_minor;
 
+	/*
+	 * No frame table allocated yet; initialize these in case we
+	 * get an error before allocating it or when trying to allocate
+	 * it, so that the attempt to release the private data on failure
+	 * doesn't crash.
+	 */
+	netmon->frame_table_size = 0;
+	netmon->frame_table = NULL;
+
 	/*
 	 * Get the offset of the frame index table.
 	 */
@@ -370,7 +379,6 @@ int netmon_open(wtap *wth, int *err, gchar **err_info)
 		if (*err == 0)
 			*err = WTAP_ERR_SHORT_READ;
 		g_free(frame_table);
-		g_free(netmon);
 		return -1;
 	}
 	netmon->frame_table_size = frame_table_size;
